#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCertDocVehicleLicense(object):

    def __init__(self):
        self._encoded_img_main = None
        self._encoded_img_vice = None
        self._engine_no = None
        self._issue_date = None
        self._model = None
        self._owner = None
        self._plate_no = None
        self._register_date = None
        self._vin = None

    @property
    def encoded_img_main(self):
        return self._encoded_img_main

    @encoded_img_main.setter
    def encoded_img_main(self, value):
        self._encoded_img_main = value
    @property
    def encoded_img_vice(self):
        return self._encoded_img_vice

    @encoded_img_vice.setter
    def encoded_img_vice(self, value):
        self._encoded_img_vice = value
    @property
    def engine_no(self):
        return self._engine_no

    @engine_no.setter
    def engine_no(self, value):
        self._engine_no = value
    @property
    def issue_date(self):
        return self._issue_date

    @issue_date.setter
    def issue_date(self, value):
        self._issue_date = value
    @property
    def model(self):
        return self._model

    @model.setter
    def model(self, value):
        self._model = value
    @property
    def owner(self):
        return self._owner

    @owner.setter
    def owner(self, value):
        self._owner = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def register_date(self):
        return self._register_date

    @register_date.setter
    def register_date(self, value):
        self._register_date = value
    @property
    def vin(self):
        return self._vin

    @vin.setter
    def vin(self, value):
        self._vin = value


    def to_alipay_dict(self):
        params = dict()
        if self.encoded_img_main:
            if hasattr(self.encoded_img_main, 'to_alipay_dict'):
                params['encoded_img_main'] = self.encoded_img_main.to_alipay_dict()
            else:
                params['encoded_img_main'] = self.encoded_img_main
        if self.encoded_img_vice:
            if hasattr(self.encoded_img_vice, 'to_alipay_dict'):
                params['encoded_img_vice'] = self.encoded_img_vice.to_alipay_dict()
            else:
                params['encoded_img_vice'] = self.encoded_img_vice
        if self.engine_no:
            if hasattr(self.engine_no, 'to_alipay_dict'):
                params['engine_no'] = self.engine_no.to_alipay_dict()
            else:
                params['engine_no'] = self.engine_no
        if self.issue_date:
            if hasattr(self.issue_date, 'to_alipay_dict'):
                params['issue_date'] = self.issue_date.to_alipay_dict()
            else:
                params['issue_date'] = self.issue_date
        if self.model:
            if hasattr(self.model, 'to_alipay_dict'):
                params['model'] = self.model.to_alipay_dict()
            else:
                params['model'] = self.model
        if self.owner:
            if hasattr(self.owner, 'to_alipay_dict'):
                params['owner'] = self.owner.to_alipay_dict()
            else:
                params['owner'] = self.owner
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.register_date:
            if hasattr(self.register_date, 'to_alipay_dict'):
                params['register_date'] = self.register_date.to_alipay_dict()
            else:
                params['register_date'] = self.register_date
        if self.vin:
            if hasattr(self.vin, 'to_alipay_dict'):
                params['vin'] = self.vin.to_alipay_dict()
            else:
                params['vin'] = self.vin
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertDocVehicleLicense()
        if 'encoded_img_main' in d:
            o.encoded_img_main = d['encoded_img_main']
        if 'encoded_img_vice' in d:
            o.encoded_img_vice = d['encoded_img_vice']
        if 'engine_no' in d:
            o.engine_no = d['engine_no']
        if 'issue_date' in d:
            o.issue_date = d['issue_date']
        if 'model' in d:
            o.model = d['model']
        if 'owner' in d:
            o.owner = d['owner']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'register_date' in d:
            o.register_date = d['register_date']
        if 'vin' in d:
            o.vin = d['vin']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCreditAutofinanceLoanCloseResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCreditAutofinanceLoanCloseResponse, self).__init__()
        self._outorderno = None

    @property
    def outorderno(self):
        return self._outorderno

    @outorderno.setter
    def outorderno(self, value):
        self._outorderno = value

    def parse_response_content(self, response_content):
        response = super(AlipayCreditAutofinanceLoanCloseResponse, self).parse_response_content(response_content)
        if 'outorderno' in response:
            self.outorderno = response['outorderno']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StuffStockOutOrderItem(object):

    def __init__(self):
        self._ext_info = None
        self._item_name = None
        self._item_quantity = None
        self._sku_no = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_quantity(self):
        return self._item_quantity

    @item_quantity.setter
    def item_quantity(self, value):
        self._item_quantity = value
    @property
    def sku_no(self):
        return self._sku_no

    @sku_no.setter
    def sku_no(self, value):
        self._sku_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_quantity:
            if hasattr(self.item_quantity, 'to_alipay_dict'):
                params['item_quantity'] = self.item_quantity.to_alipay_dict()
            else:
                params['item_quantity'] = self.item_quantity
        if self.sku_no:
            if hasattr(self.sku_no, 'to_alipay_dict'):
                params['sku_no'] = self.sku_no.to_alipay_dict()
            else:
                params['sku_no'] = self.sku_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StuffStockOutOrderItem()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_quantity' in d:
            o.item_quantity = d['item_quantity']
        if 'sku_no' in d:
            o.sku_no = d['sku_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeRefundApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeRefundApplyResponse, self).__init__()
        self._out_request_no = None
        self._out_trade_no = None
        self._refund_amount = None
        self._refund_status = None
        self._trade_no = None

    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def refund_amount(self):
        return self._refund_amount

    @refund_amount.setter
    def refund_amount(self, value):
        self._refund_amount = value
    @property
    def refund_status(self):
        return self._refund_status

    @refund_status.setter
    def refund_status(self, value):
        self._refund_status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeRefundApplyResponse, self).parse_response_content(response_content)
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'out_trade_no' in response:
            self.out_trade_no = response['out_trade_no']
        if 'refund_amount' in response:
            self.refund_amount = response['refund_amount']
        if 'refund_status' in response:
            self.refund_status = response['refund_status']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenAuthUserauthRelationshipCertifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenAuthUserauthRelationshipCertifyResponse, self).__init__()
        self._effective = None

    @property
    def effective(self):
        return self._effective

    @effective.setter
    def effective(self, value):
        self._effective = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenAuthUserauthRelationshipCertifyResponse, self).parse_response_content(response_content)
        if 'effective' in response:
            self.effective = response['effective']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbVirtualShopCategoryDishInfo(object):

    def __init__(self):
        self._dish_id = None
        self._ext_info = None
        self._sort = None

    @property
    def dish_id(self):
        return self._dish_id

    @dish_id.setter
    def dish_id(self, value):
        self._dish_id = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def sort(self):
        return self._sort

    @sort.setter
    def sort(self, value):
        self._sort = value


    def to_alipay_dict(self):
        params = dict()
        if self.dish_id:
            if hasattr(self.dish_id, 'to_alipay_dict'):
                params['dish_id'] = self.dish_id.to_alipay_dict()
            else:
                params['dish_id'] = self.dish_id
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.sort:
            if hasattr(self.sort, 'to_alipay_dict'):
                params['sort'] = self.sort.to_alipay_dict()
            else:
                params['sort'] = self.sort
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbVirtualShopCategoryDishInfo()
        if 'dish_id' in d:
            o.dish_id = d['dish_id']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'sort' in d:
            o.sort = d['sort']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntProdpaasGrmcoreSrInvalidResponse(AlipayResponse):

    def __init__(self):
        super(AntProdpaasGrmcoreSrInvalidResponse, self).__init__()
        self._flag = None
        self._suppliers = None

    @property
    def flag(self):
        return self._flag

    @flag.setter
    def flag(self, value):
        self._flag = value
    @property
    def suppliers(self):
        return self._suppliers

    @suppliers.setter
    def suppliers(self, value):
        if isinstance(value, list):
            self._suppliers = list()
            for i in value:
                self._suppliers.append(i)

    def parse_response_content(self, response_content):
        response = super(AntProdpaasGrmcoreSrInvalidResponse, self).parse_response_content(response_content)
        if 'flag' in response:
            self.flag = response['flag']
        if 'suppliers' in response:
            self.suppliers = response['suppliers']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniPluginuseconfigQueryModel(object):

    def __init__(self):
        self._page_num = None
        self._page_size = None
        self._plugin_id = None
        self._plugin_relation_status_list = None
        self._run_model_type = None

    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def plugin_id(self):
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, value):
        self._plugin_id = value
    @property
    def plugin_relation_status_list(self):
        return self._plugin_relation_status_list

    @plugin_relation_status_list.setter
    def plugin_relation_status_list(self, value):
        if isinstance(value, list):
            self._plugin_relation_status_list = list()
            for i in value:
                self._plugin_relation_status_list.append(i)
    @property
    def run_model_type(self):
        return self._run_model_type

    @run_model_type.setter
    def run_model_type(self, value):
        self._run_model_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.plugin_id:
            if hasattr(self.plugin_id, 'to_alipay_dict'):
                params['plugin_id'] = self.plugin_id.to_alipay_dict()
            else:
                params['plugin_id'] = self.plugin_id
        if self.plugin_relation_status_list:
            if isinstance(self.plugin_relation_status_list, list):
                for i in range(0, len(self.plugin_relation_status_list)):
                    element = self.plugin_relation_status_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.plugin_relation_status_list[i] = element.to_alipay_dict()
            if hasattr(self.plugin_relation_status_list, 'to_alipay_dict'):
                params['plugin_relation_status_list'] = self.plugin_relation_status_list.to_alipay_dict()
            else:
                params['plugin_relation_status_list'] = self.plugin_relation_status_list
        if self.run_model_type:
            if hasattr(self.run_model_type, 'to_alipay_dict'):
                params['run_model_type'] = self.run_model_type.to_alipay_dict()
            else:
                params['run_model_type'] = self.run_model_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniPluginuseconfigQueryModel()
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'plugin_id' in d:
            o.plugin_id = d['plugin_id']
        if 'plugin_relation_status_list' in d:
            o.plugin_relation_status_list = d['plugin_relation_status_list']
        if 'run_model_type' in d:
            o.run_model_type = d['run_model_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSceneprodLoanConfirmResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSceneprodLoanConfirmResponse, self).__init__()
        self._apply_no = None
        self._error_msg = None
        self._fin_order_no = None
        self._process_result = None
        self._request_id = None
        self._retry = None
        self._trace_id = None

    @property
    def apply_no(self):
        return self._apply_no

    @apply_no.setter
    def apply_no(self, value):
        self._apply_no = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def fin_order_no(self):
        return self._fin_order_no

    @fin_order_no.setter
    def fin_order_no(self, value):
        self._fin_order_no = value
    @property
    def process_result(self):
        return self._process_result

    @process_result.setter
    def process_result(self, value):
        self._process_result = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSceneprodLoanConfirmResponse, self).parse_response_content(response_content)
        if 'apply_no' in response:
            self.apply_no = response['apply_no']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'fin_order_no' in response:
            self.fin_order_no = response['fin_order_no']
        if 'process_result' in response:
            self.process_result = response['process_result']
        if 'request_id' in response:
            self.request_id = response['request_id']
        if 'retry' in response:
            self.retry = response['retry']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StudentInfo(object):

    def __init__(self):
        self._city_no = None
        self._class_name = None
        self._college_name = None
        self._college_no = None
        self._degree = None
        self._departments = None
        self._gmt_enrollment = None
        self._gmt_graduation = None
        self._major = None
        self._student_id = None

    @property
    def city_no(self):
        return self._city_no

    @city_no.setter
    def city_no(self, value):
        self._city_no = value
    @property
    def class_name(self):
        return self._class_name

    @class_name.setter
    def class_name(self, value):
        self._class_name = value
    @property
    def college_name(self):
        return self._college_name

    @college_name.setter
    def college_name(self, value):
        self._college_name = value
    @property
    def college_no(self):
        return self._college_no

    @college_no.setter
    def college_no(self, value):
        self._college_no = value
    @property
    def degree(self):
        return self._degree

    @degree.setter
    def degree(self, value):
        self._degree = value
    @property
    def departments(self):
        return self._departments

    @departments.setter
    def departments(self, value):
        self._departments = value
    @property
    def gmt_enrollment(self):
        return self._gmt_enrollment

    @gmt_enrollment.setter
    def gmt_enrollment(self, value):
        self._gmt_enrollment = value
    @property
    def gmt_graduation(self):
        return self._gmt_graduation

    @gmt_graduation.setter
    def gmt_graduation(self, value):
        self._gmt_graduation = value
    @property
    def major(self):
        return self._major

    @major.setter
    def major(self, value):
        self._major = value
    @property
    def student_id(self):
        return self._student_id

    @student_id.setter
    def student_id(self, value):
        self._student_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_no:
            if hasattr(self.city_no, 'to_alipay_dict'):
                params['city_no'] = self.city_no.to_alipay_dict()
            else:
                params['city_no'] = self.city_no
        if self.class_name:
            if hasattr(self.class_name, 'to_alipay_dict'):
                params['class_name'] = self.class_name.to_alipay_dict()
            else:
                params['class_name'] = self.class_name
        if self.college_name:
            if hasattr(self.college_name, 'to_alipay_dict'):
                params['college_name'] = self.college_name.to_alipay_dict()
            else:
                params['college_name'] = self.college_name
        if self.college_no:
            if hasattr(self.college_no, 'to_alipay_dict'):
                params['college_no'] = self.college_no.to_alipay_dict()
            else:
                params['college_no'] = self.college_no
        if self.degree:
            if hasattr(self.degree, 'to_alipay_dict'):
                params['degree'] = self.degree.to_alipay_dict()
            else:
                params['degree'] = self.degree
        if self.departments:
            if hasattr(self.departments, 'to_alipay_dict'):
                params['departments'] = self.departments.to_alipay_dict()
            else:
                params['departments'] = self.departments
        if self.gmt_enrollment:
            if hasattr(self.gmt_enrollment, 'to_alipay_dict'):
                params['gmt_enrollment'] = self.gmt_enrollment.to_alipay_dict()
            else:
                params['gmt_enrollment'] = self.gmt_enrollment
        if self.gmt_graduation:
            if hasattr(self.gmt_graduation, 'to_alipay_dict'):
                params['gmt_graduation'] = self.gmt_graduation.to_alipay_dict()
            else:
                params['gmt_graduation'] = self.gmt_graduation
        if self.major:
            if hasattr(self.major, 'to_alipay_dict'):
                params['major'] = self.major.to_alipay_dict()
            else:
                params['major'] = self.major
        if self.student_id:
            if hasattr(self.student_id, 'to_alipay_dict'):
                params['student_id'] = self.student_id.to_alipay_dict()
            else:
                params['student_id'] = self.student_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StudentInfo()
        if 'city_no' in d:
            o.city_no = d['city_no']
        if 'class_name' in d:
            o.class_name = d['class_name']
        if 'college_name' in d:
            o.college_name = d['college_name']
        if 'college_no' in d:
            o.college_no = d['college_no']
        if 'degree' in d:
            o.degree = d['degree']
        if 'departments' in d:
            o.departments = d['departments']
        if 'gmt_enrollment' in d:
            o.gmt_enrollment = d['gmt_enrollment']
        if 'gmt_graduation' in d:
            o.gmt_graduation = d['gmt_graduation']
        if 'major' in d:
            o.major = d['major']
        if 'student_id' in d:
            o.student_id = d['student_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FliggyPoiInfo(object):

    def __init__(self):
        self._biz_code = None
        self._msg = None
        self._poi_id = None
        self._success = None

    @property
    def biz_code(self):
        return self._biz_code

    @biz_code.setter
    def biz_code(self, value):
        self._biz_code = value
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value
    @property
    def poi_id(self):
        return self._poi_id

    @poi_id.setter
    def poi_id(self, value):
        self._poi_id = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_code:
            if hasattr(self.biz_code, 'to_alipay_dict'):
                params['biz_code'] = self.biz_code.to_alipay_dict()
            else:
                params['biz_code'] = self.biz_code
        if self.msg:
            if hasattr(self.msg, 'to_alipay_dict'):
                params['msg'] = self.msg.to_alipay_dict()
            else:
                params['msg'] = self.msg
        if self.poi_id:
            if hasattr(self.poi_id, 'to_alipay_dict'):
                params['poi_id'] = self.poi_id.to_alipay_dict()
            else:
                params['poi_id'] = self.poi_id
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FliggyPoiInfo()
        if 'biz_code' in d:
            o.biz_code = d['biz_code']
        if 'msg' in d:
            o.msg = d['msg']
        if 'poi_id' in d:
            o.poi_id = d['poi_id']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditEpEntityMonitorUploadModel(object):

    def __init__(self):
        self._entity_list = None
        self._entity_type = None
        self._solution_id = None
        self._zhima_pid = None

    @property
    def entity_list(self):
        return self._entity_list

    @entity_list.setter
    def entity_list(self, value):
        self._entity_list = value
    @property
    def entity_type(self):
        return self._entity_type

    @entity_type.setter
    def entity_type(self, value):
        self._entity_type = value
    @property
    def solution_id(self):
        return self._solution_id

    @solution_id.setter
    def solution_id(self, value):
        self._solution_id = value
    @property
    def zhima_pid(self):
        return self._zhima_pid

    @zhima_pid.setter
    def zhima_pid(self, value):
        self._zhima_pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.entity_list:
            if hasattr(self.entity_list, 'to_alipay_dict'):
                params['entity_list'] = self.entity_list.to_alipay_dict()
            else:
                params['entity_list'] = self.entity_list
        if self.entity_type:
            if hasattr(self.entity_type, 'to_alipay_dict'):
                params['entity_type'] = self.entity_type.to_alipay_dict()
            else:
                params['entity_type'] = self.entity_type
        if self.solution_id:
            if hasattr(self.solution_id, 'to_alipay_dict'):
                params['solution_id'] = self.solution_id.to_alipay_dict()
            else:
                params['solution_id'] = self.solution_id
        if self.zhima_pid:
            if hasattr(self.zhima_pid, 'to_alipay_dict'):
                params['zhima_pid'] = self.zhima_pid.to_alipay_dict()
            else:
                params['zhima_pid'] = self.zhima_pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditEpEntityMonitorUploadModel()
        if 'entity_list' in d:
            o.entity_list = d['entity_list']
        if 'entity_type' in d:
            o.entity_type = d['entity_type']
        if 'solution_id' in d:
            o.solution_id = d['solution_id']
        if 'zhima_pid' in d:
            o.zhima_pid = d['zhima_pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoSignFlowCancelModel(object):

    def __init__(self):
        self._flow_id = None
        self._revoke_reason = None

    @property
    def flow_id(self):
        return self._flow_id

    @flow_id.setter
    def flow_id(self, value):
        self._flow_id = value
    @property
    def revoke_reason(self):
        return self._revoke_reason

    @revoke_reason.setter
    def revoke_reason(self, value):
        self._revoke_reason = value


    def to_alipay_dict(self):
        params = dict()
        if self.flow_id:
            if hasattr(self.flow_id, 'to_alipay_dict'):
                params['flow_id'] = self.flow_id.to_alipay_dict()
            else:
                params['flow_id'] = self.flow_id
        if self.revoke_reason:
            if hasattr(self.revoke_reason, 'to_alipay_dict'):
                params['revoke_reason'] = self.revoke_reason.to_alipay_dict()
            else:
                params['revoke_reason'] = self.revoke_reason
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoSignFlowCancelModel()
        if 'flow_id' in d:
            o.flow_id = d['flow_id']
        if 'revoke_reason' in d:
            o.revoke_reason = d['revoke_reason']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMemberDataItemNearbyQueryModel(object):

    def __init__(self):
        self._city_code = None
        self._latitude = None
        self._longitude = None
        self._page_size = None
        self._page_start = None
        self._radius = None
        self._user_id = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def page_start(self):
        return self._page_start

    @page_start.setter
    def page_start(self, value):
        self._page_start = value
    @property
    def radius(self):
        return self._radius

    @radius.setter
    def radius(self, value):
        self._radius = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.page_start:
            if hasattr(self.page_start, 'to_alipay_dict'):
                params['page_start'] = self.page_start.to_alipay_dict()
            else:
                params['page_start'] = self.page_start
        if self.radius:
            if hasattr(self.radius, 'to_alipay_dict'):
                params['radius'] = self.radius.to_alipay_dict()
            else:
                params['radius'] = self.radius
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMemberDataItemNearbyQueryModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'page_start' in d:
            o.page_start = d['page_start']
        if 'radius' in d:
            o.radius = d['radius']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeviceServiceBaseVO import DeviceServiceBaseVO
from alipay.aop.api.domain.DeviceServiceBaseVO import DeviceServiceBaseVO


class DeviceServiceVO(object):

    def __init__(self):
        self._device_service_base = None
        self._parent_base = None
        self._service_key = None
        self._version_no = None

    @property
    def device_service_base(self):
        return self._device_service_base

    @device_service_base.setter
    def device_service_base(self, value):
        if isinstance(value, DeviceServiceBaseVO):
            self._device_service_base = value
        else:
            self._device_service_base = DeviceServiceBaseVO.from_alipay_dict(value)
    @property
    def parent_base(self):
        return self._parent_base

    @parent_base.setter
    def parent_base(self, value):
        if isinstance(value, DeviceServiceBaseVO):
            self._parent_base = value
        else:
            self._parent_base = DeviceServiceBaseVO.from_alipay_dict(value)
    @property
    def service_key(self):
        return self._service_key

    @service_key.setter
    def service_key(self, value):
        self._service_key = value
    @property
    def version_no(self):
        return self._version_no

    @version_no.setter
    def version_no(self, value):
        self._version_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_service_base:
            if hasattr(self.device_service_base, 'to_alipay_dict'):
                params['device_service_base'] = self.device_service_base.to_alipay_dict()
            else:
                params['device_service_base'] = self.device_service_base
        if self.parent_base:
            if hasattr(self.parent_base, 'to_alipay_dict'):
                params['parent_base'] = self.parent_base.to_alipay_dict()
            else:
                params['parent_base'] = self.parent_base
        if self.service_key:
            if hasattr(self.service_key, 'to_alipay_dict'):
                params['service_key'] = self.service_key.to_alipay_dict()
            else:
                params['service_key'] = self.service_key
        if self.version_no:
            if hasattr(self.version_no, 'to_alipay_dict'):
                params['version_no'] = self.version_no.to_alipay_dict()
            else:
                params['version_no'] = self.version_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceServiceVO()
        if 'device_service_base' in d:
            o.device_service_base = d['device_service_base']
        if 'parent_base' in d:
            o.parent_base = d['parent_base']
        if 'service_key' in d:
            o.service_key = d['service_key']
        if 'version_no' in d:
            o.version_no = d['version_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DataDim(object):

    def __init__(self):
        self._dim_name = None
        self._dim_type = None
        self._dim_value = None

    @property
    def dim_name(self):
        return self._dim_name

    @dim_name.setter
    def dim_name(self, value):
        self._dim_name = value
    @property
    def dim_type(self):
        return self._dim_type

    @dim_type.setter
    def dim_type(self, value):
        self._dim_type = value
    @property
    def dim_value(self):
        return self._dim_value

    @dim_value.setter
    def dim_value(self, value):
        self._dim_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.dim_name:
            if hasattr(self.dim_name, 'to_alipay_dict'):
                params['dim_name'] = self.dim_name.to_alipay_dict()
            else:
                params['dim_name'] = self.dim_name
        if self.dim_type:
            if hasattr(self.dim_type, 'to_alipay_dict'):
                params['dim_type'] = self.dim_type.to_alipay_dict()
            else:
                params['dim_type'] = self.dim_type
        if self.dim_value:
            if hasattr(self.dim_value, 'to_alipay_dict'):
                params['dim_value'] = self.dim_value.to_alipay_dict()
            else:
                params['dim_value'] = self.dim_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DataDim()
        if 'dim_name' in d:
            o.dim_name = d['dim_name']
        if 'dim_type' in d:
            o.dim_type = d['dim_type']
        if 'dim_value' in d:
            o.dim_value = d['dim_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TextInstance import TextInstance
from alipay.aop.api.domain.MaterialDetail import MaterialDetail
from alipay.aop.api.domain.CreativeRefuseExtendInfo import CreativeRefuseExtendInfo
from alipay.aop.api.domain.TextInstance import TextInstance
from alipay.aop.api.domain.MaterialDetail import MaterialDetail


class CreativeDetail(object):

    def __init__(self):
        self._action_type = None
        self._audit_order_id = None
        self._batch_tag = None
        self._click = None
        self._cost = None
        self._creative_id = None
        self._creative_outer_id = None
        self._desc_list = None
        self._extend_info = None
        self._group_outer_id = None
        self._img_list = None
        self._impression = None
        self._lbs_list = None
        self._name = None
        self._plan_outer_id = None
        self._principal_id = None
        self._refuse_extend_info = None
        self._refuse_reason = None
        self._region_list = None
        self._status = None
        self._store_id = None
        self._target_app_id = None
        self._target_url = None
        self._template_id = None
        self._title_list = None
        self._user_id = None
        self._video_list = None

    @property
    def action_type(self):
        return self._action_type

    @action_type.setter
    def action_type(self, value):
        self._action_type = value
    @property
    def audit_order_id(self):
        return self._audit_order_id

    @audit_order_id.setter
    def audit_order_id(self, value):
        self._audit_order_id = value
    @property
    def batch_tag(self):
        return self._batch_tag

    @batch_tag.setter
    def batch_tag(self, value):
        self._batch_tag = value
    @property
    def click(self):
        return self._click

    @click.setter
    def click(self, value):
        self._click = value
    @property
    def cost(self):
        return self._cost

    @cost.setter
    def cost(self, value):
        self._cost = value
    @property
    def creative_id(self):
        return self._creative_id

    @creative_id.setter
    def creative_id(self, value):
        self._creative_id = value
    @property
    def creative_outer_id(self):
        return self._creative_outer_id

    @creative_outer_id.setter
    def creative_outer_id(self, value):
        self._creative_outer_id = value
    @property
    def desc_list(self):
        return self._desc_list

    @desc_list.setter
    def desc_list(self, value):
        if isinstance(value, list):
            self._desc_list = list()
            for i in value:
                if isinstance(i, TextInstance):
                    self._desc_list.append(i)
                else:
                    self._desc_list.append(TextInstance.from_alipay_dict(i))
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def group_outer_id(self):
        return self._group_outer_id

    @group_outer_id.setter
    def group_outer_id(self, value):
        self._group_outer_id = value
    @property
    def img_list(self):
        return self._img_list

    @img_list.setter
    def img_list(self, value):
        if isinstance(value, list):
            self._img_list = list()
            for i in value:
                if isinstance(i, MaterialDetail):
                    self._img_list.append(i)
                else:
                    self._img_list.append(MaterialDetail.from_alipay_dict(i))
    @property
    def impression(self):
        return self._impression

    @impression.setter
    def impression(self, value):
        self._impression = value
    @property
    def lbs_list(self):
        return self._lbs_list

    @lbs_list.setter
    def lbs_list(self, value):
        if isinstance(value, list):
            self._lbs_list = list()
            for i in value:
                self._lbs_list.append(i)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def plan_outer_id(self):
        return self._plan_outer_id

    @plan_outer_id.setter
    def plan_outer_id(self, value):
        self._plan_outer_id = value
    @property
    def principal_id(self):
        return self._principal_id

    @principal_id.setter
    def principal_id(self, value):
        self._principal_id = value
    @property
    def refuse_extend_info(self):
        return self._refuse_extend_info

    @refuse_extend_info.setter
    def refuse_extend_info(self, value):
        if isinstance(value, CreativeRefuseExtendInfo):
            self._refuse_extend_info = value
        else:
            self._refuse_extend_info = CreativeRefuseExtendInfo.from_alipay_dict(value)
    @property
    def refuse_reason(self):
        return self._refuse_reason

    @refuse_reason.setter
    def refuse_reason(self, value):
        self._refuse_reason = value
    @property
    def region_list(self):
        return self._region_list

    @region_list.setter
    def region_list(self, value):
        if isinstance(value, list):
            self._region_list = list()
            for i in value:
                self._region_list.append(i)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def target_app_id(self):
        return self._target_app_id

    @target_app_id.setter
    def target_app_id(self, value):
        self._target_app_id = value
    @property
    def target_url(self):
        return self._target_url

    @target_url.setter
    def target_url(self, value):
        self._target_url = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def title_list(self):
        return self._title_list

    @title_list.setter
    def title_list(self, value):
        if isinstance(value, list):
            self._title_list = list()
            for i in value:
                if isinstance(i, TextInstance):
                    self._title_list.append(i)
                else:
                    self._title_list.append(TextInstance.from_alipay_dict(i))
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def video_list(self):
        return self._video_list

    @video_list.setter
    def video_list(self, value):
        if isinstance(value, list):
            self._video_list = list()
            for i in value:
                if isinstance(i, MaterialDetail):
                    self._video_list.append(i)
                else:
                    self._video_list.append(MaterialDetail.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.action_type:
            if hasattr(self.action_type, 'to_alipay_dict'):
                params['action_type'] = self.action_type.to_alipay_dict()
            else:
                params['action_type'] = self.action_type
        if self.audit_order_id:
            if hasattr(self.audit_order_id, 'to_alipay_dict'):
                params['audit_order_id'] = self.audit_order_id.to_alipay_dict()
            else:
                params['audit_order_id'] = self.audit_order_id
        if self.batch_tag:
            if hasattr(self.batch_tag, 'to_alipay_dict'):
                params['batch_tag'] = self.batch_tag.to_alipay_dict()
            else:
                params['batch_tag'] = self.batch_tag
        if self.click:
            if hasattr(self.click, 'to_alipay_dict'):
                params['click'] = self.click.to_alipay_dict()
            else:
                params['click'] = self.click
        if self.cost:
            if hasattr(self.cost, 'to_alipay_dict'):
                params['cost'] = self.cost.to_alipay_dict()
            else:
                params['cost'] = self.cost
        if self.creative_id:
            if hasattr(self.creative_id, 'to_alipay_dict'):
                params['creative_id'] = self.creative_id.to_alipay_dict()
            else:
                params['creative_id'] = self.creative_id
        if self.creative_outer_id:
            if hasattr(self.creative_outer_id, 'to_alipay_dict'):
                params['creative_outer_id'] = self.creative_outer_id.to_alipay_dict()
            else:
                params['creative_outer_id'] = self.creative_outer_id
        if self.desc_list:
            if isinstance(self.desc_list, list):
                for i in range(0, len(self.desc_list)):
                    element = self.desc_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.desc_list[i] = element.to_alipay_dict()
            if hasattr(self.desc_list, 'to_alipay_dict'):
                params['desc_list'] = self.desc_list.to_alipay_dict()
            else:
                params['desc_list'] = self.desc_list
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.group_outer_id:
            if hasattr(self.group_outer_id, 'to_alipay_dict'):
                params['group_outer_id'] = self.group_outer_id.to_alipay_dict()
            else:
                params['group_outer_id'] = self.group_outer_id
        if self.img_list:
            if isinstance(self.img_list, list):
                for i in range(0, len(self.img_list)):
                    element = self.img_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.img_list[i] = element.to_alipay_dict()
            if hasattr(self.img_list, 'to_alipay_dict'):
                params['img_list'] = self.img_list.to_alipay_dict()
            else:
                params['img_list'] = self.img_list
        if self.impression:
            if hasattr(self.impression, 'to_alipay_dict'):
                params['impression'] = self.impression.to_alipay_dict()
            else:
                params['impression'] = self.impression
        if self.lbs_list:
            if isinstance(self.lbs_list, list):
                for i in range(0, len(self.lbs_list)):
                    element = self.lbs_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.lbs_list[i] = element.to_alipay_dict()
            if hasattr(self.lbs_list, 'to_alipay_dict'):
                params['lbs_list'] = self.lbs_list.to_alipay_dict()
            else:
                params['lbs_list'] = self.lbs_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.plan_outer_id:
            if hasattr(self.plan_outer_id, 'to_alipay_dict'):
                params['plan_outer_id'] = self.plan_outer_id.to_alipay_dict()
            else:
                params['plan_outer_id'] = self.plan_outer_id
        if self.principal_id:
            if hasattr(self.principal_id, 'to_alipay_dict'):
                params['principal_id'] = self.principal_id.to_alipay_dict()
            else:
                params['principal_id'] = self.principal_id
        if self.refuse_extend_info:
            if hasattr(self.refuse_extend_info, 'to_alipay_dict'):
                params['refuse_extend_info'] = self.refuse_extend_info.to_alipay_dict()
            else:
                params['refuse_extend_info'] = self.refuse_extend_info
        if self.refuse_reason:
            if hasattr(self.refuse_reason, 'to_alipay_dict'):
                params['refuse_reason'] = self.refuse_reason.to_alipay_dict()
            else:
                params['refuse_reason'] = self.refuse_reason
        if self.region_list:
            if isinstance(self.region_list, list):
                for i in range(0, len(self.region_list)):
                    element = self.region_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.region_list[i] = element.to_alipay_dict()
            if hasattr(self.region_list, 'to_alipay_dict'):
                params['region_list'] = self.region_list.to_alipay_dict()
            else:
                params['region_list'] = self.region_list
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.target_app_id:
            if hasattr(self.target_app_id, 'to_alipay_dict'):
                params['target_app_id'] = self.target_app_id.to_alipay_dict()
            else:
                params['target_app_id'] = self.target_app_id
        if self.target_url:
            if hasattr(self.target_url, 'to_alipay_dict'):
                params['target_url'] = self.target_url.to_alipay_dict()
            else:
                params['target_url'] = self.target_url
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.title_list:
            if isinstance(self.title_list, list):
                for i in range(0, len(self.title_list)):
                    element = self.title_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.title_list[i] = element.to_alipay_dict()
            if hasattr(self.title_list, 'to_alipay_dict'):
                params['title_list'] = self.title_list.to_alipay_dict()
            else:
                params['title_list'] = self.title_list
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.video_list:
            if isinstance(self.video_list, list):
                for i in range(0, len(self.video_list)):
                    element = self.video_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.video_list[i] = element.to_alipay_dict()
            if hasattr(self.video_list, 'to_alipay_dict'):
                params['video_list'] = self.video_list.to_alipay_dict()
            else:
                params['video_list'] = self.video_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CreativeDetail()
        if 'action_type' in d:
            o.action_type = d['action_type']
        if 'audit_order_id' in d:
            o.audit_order_id = d['audit_order_id']
        if 'batch_tag' in d:
            o.batch_tag = d['batch_tag']
        if 'click' in d:
            o.click = d['click']
        if 'cost' in d:
            o.cost = d['cost']
        if 'creative_id' in d:
            o.creative_id = d['creative_id']
        if 'creative_outer_id' in d:
            o.creative_outer_id = d['creative_outer_id']
        if 'desc_list' in d:
            o.desc_list = d['desc_list']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'group_outer_id' in d:
            o.group_outer_id = d['group_outer_id']
        if 'img_list' in d:
            o.img_list = d['img_list']
        if 'impression' in d:
            o.impression = d['impression']
        if 'lbs_list' in d:
            o.lbs_list = d['lbs_list']
        if 'name' in d:
            o.name = d['name']
        if 'plan_outer_id' in d:
            o.plan_outer_id = d['plan_outer_id']
        if 'principal_id' in d:
            o.principal_id = d['principal_id']
        if 'refuse_extend_info' in d:
            o.refuse_extend_info = d['refuse_extend_info']
        if 'refuse_reason' in d:
            o.refuse_reason = d['refuse_reason']
        if 'region_list' in d:
            o.region_list = d['region_list']
        if 'status' in d:
            o.status = d['status']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'target_app_id' in d:
            o.target_app_id = d['target_app_id']
        if 'target_url' in d:
            o.target_url = d['target_url']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'title_list' in d:
            o.title_list = d['title_list']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'video_list' in d:
            o.video_list = d['video_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.OrderExtInfo import OrderExtInfo


class AntMerchantExpandTradeorderEventSendModel(object):

    def __init__(self):
        self._event = None
        self._ext_info = None
        self._order_id = None

    @property
    def event(self):
        return self._event

    @event.setter
    def event(self, value):
        self._event = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, OrderExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(OrderExtInfo.from_alipay_dict(i))
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.event:
            if hasattr(self.event, 'to_alipay_dict'):
                params['event'] = self.event.to_alipay_dict()
            else:
                params['event'] = self.event
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandTradeorderEventSendModel()
        if 'event' in d:
            o.event = d['event']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'order_id' in d:
            o.order_id = d['order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingCampaignMemberAuthApplyModel(object):

    def __init__(self):
        self._auth_token = None

    @property
    def auth_token(self):
        return self._auth_token

    @auth_token.setter
    def auth_token(self, value):
        self._auth_token = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_token:
            if hasattr(self.auth_token, 'to_alipay_dict'):
                params['auth_token'] = self.auth_token.to_alipay_dict()
            else:
                params['auth_token'] = self.auth_token
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignMemberAuthApplyModel()
        if 'auth_token' in d:
            o.auth_token = d['auth_token']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CloudResumeEducationExperience(object):

    def __init__(self):
        self._degree = None
        self._education_status = None
        self._location = None
        self._month = None
        self._school_name = None
        self._year = None

    @property
    def degree(self):
        return self._degree

    @degree.setter
    def degree(self, value):
        self._degree = value
    @property
    def education_status(self):
        return self._education_status

    @education_status.setter
    def education_status(self, value):
        self._education_status = value
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        self._location = value
    @property
    def month(self):
        return self._month

    @month.setter
    def month(self, value):
        self._month = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def year(self):
        return self._year

    @year.setter
    def year(self, value):
        self._year = value


    def to_alipay_dict(self):
        params = dict()
        if self.degree:
            if hasattr(self.degree, 'to_alipay_dict'):
                params['degree'] = self.degree.to_alipay_dict()
            else:
                params['degree'] = self.degree
        if self.education_status:
            if hasattr(self.education_status, 'to_alipay_dict'):
                params['education_status'] = self.education_status.to_alipay_dict()
            else:
                params['education_status'] = self.education_status
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.month:
            if hasattr(self.month, 'to_alipay_dict'):
                params['month'] = self.month.to_alipay_dict()
            else:
                params['month'] = self.month
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.year:
            if hasattr(self.year, 'to_alipay_dict'):
                params['year'] = self.year.to_alipay_dict()
            else:
                params['year'] = self.year
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CloudResumeEducationExperience()
        if 'degree' in d:
            o.degree = d['degree']
        if 'education_status' in d:
            o.education_status = d['education_status']
        if 'location' in d:
            o.location = d['location']
        if 'month' in d:
            o.month = d['month']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'year' in d:
            o.year = d['year']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopPosSchedule(object):

    def __init__(self):
        self._end_time = None
        self._id = None
        self._name = None
        self._sort = None
        self._start_time = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def sort(self):
        return self._sort

    @sort.setter
    def sort(self, value):
        self._sort = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.sort:
            if hasattr(self.sort, 'to_alipay_dict'):
                params['sort'] = self.sort.to_alipay_dict()
            else:
                params['sort'] = self.sort
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopPosSchedule()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'id' in d:
            o.id = d['id']
        if 'name' in d:
            o.name = d['name']
        if 'sort' in d:
            o.sort = d['sort']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCreditCreditriskDataPutResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCreditCreditriskDataPutResponse, self).__init__()
        self._dataid = None

    @property
    def dataid(self):
        return self._dataid

    @dataid.setter
    def dataid(self, value):
        self._dataid = value

    def parse_response_content(self, response_content):
        response = super(AlipayCreditCreditriskDataPutResponse, self).parse_response_content(response_content)
        if 'dataid' in response:
            self.dataid = response['dataid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.MerchantEffectQueryResult import MerchantEffectQueryResult


class AlipayDataAiserviceSmartpriceMerchanteffectQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataAiserviceSmartpriceMerchanteffectQueryResponse, self).__init__()
        self._result = None
        self._unit_id = None

    @property
    def result(self):
        return self._result

    @result.setter
    def result(self, value):
        if isinstance(value, list):
            self._result = list()
            for i in value:
                if isinstance(i, MerchantEffectQueryResult):
                    self._result.append(i)
                else:
                    self._result.append(MerchantEffectQueryResult.from_alipay_dict(i))
    @property
    def unit_id(self):
        return self._unit_id

    @unit_id.setter
    def unit_id(self, value):
        self._unit_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataAiserviceSmartpriceMerchanteffectQueryResponse, self).parse_response_content(response_content)
        if 'result' in response:
            self.result = response['result']
        if 'unit_id' in response:
            self.unit_id = response['unit_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppBillGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppBillGetResponse, self).__init__()
        self._alipay_order_no = None
        self._bill_date = None
        self._bill_key = None
        self._charge_inst = None
        self._charge_inst_name = None
        self._merchant_order_no = None
        self._order_status = None
        self._order_type = None
        self._owner_name = None
        self._pay_amount = None
        self._pay_time = None
        self._service_amount = None
        self._sub_order_type = None
        self._traffic_location = None
        self._traffic_regulations = None

    @property
    def alipay_order_no(self):
        return self._alipay_order_no

    @alipay_order_no.setter
    def alipay_order_no(self, value):
        self._alipay_order_no = value
    @property
    def bill_date(self):
        return self._bill_date

    @bill_date.setter
    def bill_date(self, value):
        self._bill_date = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def charge_inst_name(self):
        return self._charge_inst_name

    @charge_inst_name.setter
    def charge_inst_name(self, value):
        self._charge_inst_name = value
    @property
    def merchant_order_no(self):
        return self._merchant_order_no

    @merchant_order_no.setter
    def merchant_order_no(self, value):
        self._merchant_order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def owner_name(self):
        return self._owner_name

    @owner_name.setter
    def owner_name(self, value):
        self._owner_name = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def pay_time(self):
        return self._pay_time

    @pay_time.setter
    def pay_time(self, value):
        self._pay_time = value
    @property
    def service_amount(self):
        return self._service_amount

    @service_amount.setter
    def service_amount(self, value):
        self._service_amount = value
    @property
    def sub_order_type(self):
        return self._sub_order_type

    @sub_order_type.setter
    def sub_order_type(self, value):
        self._sub_order_type = value
    @property
    def traffic_location(self):
        return self._traffic_location

    @traffic_location.setter
    def traffic_location(self, value):
        self._traffic_location = value
    @property
    def traffic_regulations(self):
        return self._traffic_regulations

    @traffic_regulations.setter
    def traffic_regulations(self, value):
        self._traffic_regulations = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppBillGetResponse, self).parse_response_content(response_content)
        if 'alipay_order_no' in response:
            self.alipay_order_no = response['alipay_order_no']
        if 'bill_date' in response:
            self.bill_date = response['bill_date']
        if 'bill_key' in response:
            self.bill_key = response['bill_key']
        if 'charge_inst' in response:
            self.charge_inst = response['charge_inst']
        if 'charge_inst_name' in response:
            self.charge_inst_name = response['charge_inst_name']
        if 'merchant_order_no' in response:
            self.merchant_order_no = response['merchant_order_no']
        if 'order_status' in response:
            self.order_status = response['order_status']
        if 'order_type' in response:
            self.order_type = response['order_type']
        if 'owner_name' in response:
            self.owner_name = response['owner_name']
        if 'pay_amount' in response:
            self.pay_amount = response['pay_amount']
        if 'pay_time' in response:
            self.pay_time = response['pay_time']
        if 'service_amount' in response:
            self.service_amount = response['service_amount']
        if 'sub_order_type' in response:
            self.sub_order_type = response['sub_order_type']
        if 'traffic_location' in response:
            self.traffic_location = response['traffic_location']
        if 'traffic_regulations' in response:
            self.traffic_regulations = response['traffic_regulations']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CateInfoVO import CateInfoVO


class StageCateInfoVO(object):

    def __init__(self):
        self._cate_infos = None
        self._code = None
        self._name = None

    @property
    def cate_infos(self):
        return self._cate_infos

    @cate_infos.setter
    def cate_infos(self, value):
        if isinstance(value, list):
            self._cate_infos = list()
            for i in value:
                if isinstance(i, CateInfoVO):
                    self._cate_infos.append(i)
                else:
                    self._cate_infos.append(CateInfoVO.from_alipay_dict(i))
    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value


    def to_alipay_dict(self):
        params = dict()
        if self.cate_infos:
            if isinstance(self.cate_infos, list):
                for i in range(0, len(self.cate_infos)):
                    element = self.cate_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cate_infos[i] = element.to_alipay_dict()
            if hasattr(self.cate_infos, 'to_alipay_dict'):
                params['cate_infos'] = self.cate_infos.to_alipay_dict()
            else:
                params['cate_infos'] = self.cate_infos
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StageCateInfoVO()
        if 'cate_infos' in d:
            o.cate_infos = d['cate_infos']
        if 'code' in d:
            o.code = d['code']
        if 'name' in d:
            o.name = d['name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PromoOperatorInfo import PromoOperatorInfo


class KoubeiMarketingCampaignIntelligentPromoConsultModel(object):

    def __init__(self):
        self._ext_info = None
        self._operator_context = None
        self._out_request_no = None
        self._parent_promo_id = None
        self._partner_id = None
        self._shop_ids = None
        self._template_code = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def operator_context(self):
        return self._operator_context

    @operator_context.setter
    def operator_context(self, value):
        if isinstance(value, PromoOperatorInfo):
            self._operator_context = value
        else:
            self._operator_context = PromoOperatorInfo.from_alipay_dict(value)
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def parent_promo_id(self):
        return self._parent_promo_id

    @parent_promo_id.setter
    def parent_promo_id(self, value):
        self._parent_promo_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def template_code(self):
        return self._template_code

    @template_code.setter
    def template_code(self, value):
        self._template_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.operator_context:
            if hasattr(self.operator_context, 'to_alipay_dict'):
                params['operator_context'] = self.operator_context.to_alipay_dict()
            else:
                params['operator_context'] = self.operator_context
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.parent_promo_id:
            if hasattr(self.parent_promo_id, 'to_alipay_dict'):
                params['parent_promo_id'] = self.parent_promo_id.to_alipay_dict()
            else:
                params['parent_promo_id'] = self.parent_promo_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.template_code:
            if hasattr(self.template_code, 'to_alipay_dict'):
                params['template_code'] = self.template_code.to_alipay_dict()
            else:
                params['template_code'] = self.template_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingCampaignIntelligentPromoConsultModel()
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'operator_context' in d:
            o.operator_context = d['operator_context']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'parent_promo_id' in d:
            o.parent_promo_id = d['parent_promo_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'template_code' in d:
            o.template_code = d['template_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserCertifyInfoApplyModel(object):

    def __init__(self):
        self._agent_auth_letter_picture = None
        self._agent_cert_card_assist_picture = None
        self._agent_cert_card_info_picture = None
        self._agent_cert_expired_date = None
        self._agent_cert_no = None
        self._agent_cert_type = None
        self._agent_name = None
        self._biz_from = None
        self._contact_mobile = None
        self._legal_cert_card_assist_picture = None
        self._legal_cert_card_info_picture = None
        self._legal_cert_expired_date = None
        self._legal_cert_no = None
        self._legal_cert_type = None
        self._legal_name = None
        self._org_address = None
        self._org_business_scope = None
        self._org_city = None
        self._org_country = None
        self._org_main_cert_expired_date = None
        self._org_main_cert_no = None
        self._org_main_cert_picture = None
        self._org_name = None
        self._org_province = None
        self._org_type = None
        self._register_capital = None
        self._remit_check = None
        self._user_id = None

    @property
    def agent_auth_letter_picture(self):
        return self._agent_auth_letter_picture

    @agent_auth_letter_picture.setter
    def agent_auth_letter_picture(self, value):
        self._agent_auth_letter_picture = value
    @property
    def agent_cert_card_assist_picture(self):
        return self._agent_cert_card_assist_picture

    @agent_cert_card_assist_picture.setter
    def agent_cert_card_assist_picture(self, value):
        self._agent_cert_card_assist_picture = value
    @property
    def agent_cert_card_info_picture(self):
        return self._agent_cert_card_info_picture

    @agent_cert_card_info_picture.setter
    def agent_cert_card_info_picture(self, value):
        self._agent_cert_card_info_picture = value
    @property
    def agent_cert_expired_date(self):
        return self._agent_cert_expired_date

    @agent_cert_expired_date.setter
    def agent_cert_expired_date(self, value):
        self._agent_cert_expired_date = value
    @property
    def agent_cert_no(self):
        return self._agent_cert_no

    @agent_cert_no.setter
    def agent_cert_no(self, value):
        self._agent_cert_no = value
    @property
    def agent_cert_type(self):
        return self._agent_cert_type

    @agent_cert_type.setter
    def agent_cert_type(self, value):
        self._agent_cert_type = value
    @property
    def agent_name(self):
        return self._agent_name

    @agent_name.setter
    def agent_name(self, value):
        self._agent_name = value
    @property
    def biz_from(self):
        return self._biz_from

    @biz_from.setter
    def biz_from(self, value):
        self._biz_from = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def legal_cert_card_assist_picture(self):
        return self._legal_cert_card_assist_picture

    @legal_cert_card_assist_picture.setter
    def legal_cert_card_assist_picture(self, value):
        self._legal_cert_card_assist_picture = value
    @property
    def legal_cert_card_info_picture(self):
        return self._legal_cert_card_info_picture

    @legal_cert_card_info_picture.setter
    def legal_cert_card_info_picture(self, value):
        self._legal_cert_card_info_picture = value
    @property
    def legal_cert_expired_date(self):
        return self._legal_cert_expired_date

    @legal_cert_expired_date.setter
    def legal_cert_expired_date(self, value):
        self._legal_cert_expired_date = value
    @property
    def legal_cert_no(self):
        return self._legal_cert_no

    @legal_cert_no.setter
    def legal_cert_no(self, value):
        self._legal_cert_no = value
    @property
    def legal_cert_type(self):
        return self._legal_cert_type

    @legal_cert_type.setter
    def legal_cert_type(self, value):
        self._legal_cert_type = value
    @property
    def legal_name(self):
        return self._legal_name

    @legal_name.setter
    def legal_name(self, value):
        self._legal_name = value
    @property
    def org_address(self):
        return self._org_address

    @org_address.setter
    def org_address(self, value):
        self._org_address = value
    @property
    def org_business_scope(self):
        return self._org_business_scope

    @org_business_scope.setter
    def org_business_scope(self, value):
        self._org_business_scope = value
    @property
    def org_city(self):
        return self._org_city

    @org_city.setter
    def org_city(self, value):
        self._org_city = value
    @property
    def org_country(self):
        return self._org_country

    @org_country.setter
    def org_country(self, value):
        self._org_country = value
    @property
    def org_main_cert_expired_date(self):
        return self._org_main_cert_expired_date

    @org_main_cert_expired_date.setter
    def org_main_cert_expired_date(self, value):
        self._org_main_cert_expired_date = value
    @property
    def org_main_cert_no(self):
        return self._org_main_cert_no

    @org_main_cert_no.setter
    def org_main_cert_no(self, value):
        self._org_main_cert_no = value
    @property
    def org_main_cert_picture(self):
        return self._org_main_cert_picture

    @org_main_cert_picture.setter
    def org_main_cert_picture(self, value):
        self._org_main_cert_picture = value
    @property
    def org_name(self):
        return self._org_name

    @org_name.setter
    def org_name(self, value):
        self._org_name = value
    @property
    def org_province(self):
        return self._org_province

    @org_province.setter
    def org_province(self, value):
        self._org_province = value
    @property
    def org_type(self):
        return self._org_type

    @org_type.setter
    def org_type(self, value):
        self._org_type = value
    @property
    def register_capital(self):
        return self._register_capital

    @register_capital.setter
    def register_capital(self, value):
        self._register_capital = value
    @property
    def remit_check(self):
        return self._remit_check

    @remit_check.setter
    def remit_check(self, value):
        self._remit_check = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_auth_letter_picture:
            if hasattr(self.agent_auth_letter_picture, 'to_alipay_dict'):
                params['agent_auth_letter_picture'] = self.agent_auth_letter_picture.to_alipay_dict()
            else:
                params['agent_auth_letter_picture'] = self.agent_auth_letter_picture
        if self.agent_cert_card_assist_picture:
            if hasattr(self.agent_cert_card_assist_picture, 'to_alipay_dict'):
                params['agent_cert_card_assist_picture'] = self.agent_cert_card_assist_picture.to_alipay_dict()
            else:
                params['agent_cert_card_assist_picture'] = self.agent_cert_card_assist_picture
        if self.agent_cert_card_info_picture:
            if hasattr(self.agent_cert_card_info_picture, 'to_alipay_dict'):
                params['agent_cert_card_info_picture'] = self.agent_cert_card_info_picture.to_alipay_dict()
            else:
                params['agent_cert_card_info_picture'] = self.agent_cert_card_info_picture
        if self.agent_cert_expired_date:
            if hasattr(self.agent_cert_expired_date, 'to_alipay_dict'):
                params['agent_cert_expired_date'] = self.agent_cert_expired_date.to_alipay_dict()
            else:
                params['agent_cert_expired_date'] = self.agent_cert_expired_date
        if self.agent_cert_no:
            if hasattr(self.agent_cert_no, 'to_alipay_dict'):
                params['agent_cert_no'] = self.agent_cert_no.to_alipay_dict()
            else:
                params['agent_cert_no'] = self.agent_cert_no
        if self.agent_cert_type:
            if hasattr(self.agent_cert_type, 'to_alipay_dict'):
                params['agent_cert_type'] = self.agent_cert_type.to_alipay_dict()
            else:
                params['agent_cert_type'] = self.agent_cert_type
        if self.agent_name:
            if hasattr(self.agent_name, 'to_alipay_dict'):
                params['agent_name'] = self.agent_name.to_alipay_dict()
            else:
                params['agent_name'] = self.agent_name
        if self.biz_from:
            if hasattr(self.biz_from, 'to_alipay_dict'):
                params['biz_from'] = self.biz_from.to_alipay_dict()
            else:
                params['biz_from'] = self.biz_from
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.legal_cert_card_assist_picture:
            if hasattr(self.legal_cert_card_assist_picture, 'to_alipay_dict'):
                params['legal_cert_card_assist_picture'] = self.legal_cert_card_assist_picture.to_alipay_dict()
            else:
                params['legal_cert_card_assist_picture'] = self.legal_cert_card_assist_picture
        if self.legal_cert_card_info_picture:
            if hasattr(self.legal_cert_card_info_picture, 'to_alipay_dict'):
                params['legal_cert_card_info_picture'] = self.legal_cert_card_info_picture.to_alipay_dict()
            else:
                params['legal_cert_card_info_picture'] = self.legal_cert_card_info_picture
        if self.legal_cert_expired_date:
            if hasattr(self.legal_cert_expired_date, 'to_alipay_dict'):
                params['legal_cert_expired_date'] = self.legal_cert_expired_date.to_alipay_dict()
            else:
                params['legal_cert_expired_date'] = self.legal_cert_expired_date
        if self.legal_cert_no:
            if hasattr(self.legal_cert_no, 'to_alipay_dict'):
                params['legal_cert_no'] = self.legal_cert_no.to_alipay_dict()
            else:
                params['legal_cert_no'] = self.legal_cert_no
        if self.legal_cert_type:
            if hasattr(self.legal_cert_type, 'to_alipay_dict'):
                params['legal_cert_type'] = self.legal_cert_type.to_alipay_dict()
            else:
                params['legal_cert_type'] = self.legal_cert_type
        if self.legal_name:
            if hasattr(self.legal_name, 'to_alipay_dict'):
                params['legal_name'] = self.legal_name.to_alipay_dict()
            else:
                params['legal_name'] = self.legal_name
        if self.org_address:
            if hasattr(self.org_address, 'to_alipay_dict'):
                params['org_address'] = self.org_address.to_alipay_dict()
            else:
                params['org_address'] = self.org_address
        if self.org_business_scope:
            if hasattr(self.org_business_scope, 'to_alipay_dict'):
                params['org_business_scope'] = self.org_business_scope.to_alipay_dict()
            else:
                params['org_business_scope'] = self.org_business_scope
        if self.org_city:
            if hasattr(self.org_city, 'to_alipay_dict'):
                params['org_city'] = self.org_city.to_alipay_dict()
            else:
                params['org_city'] = self.org_city
        if self.org_country:
            if hasattr(self.org_country, 'to_alipay_dict'):
                params['org_country'] = self.org_country.to_alipay_dict()
            else:
                params['org_country'] = self.org_country
        if self.org_main_cert_expired_date:
            if hasattr(self.org_main_cert_expired_date, 'to_alipay_dict'):
                params['org_main_cert_expired_date'] = self.org_main_cert_expired_date.to_alipay_dict()
            else:
                params['org_main_cert_expired_date'] = self.org_main_cert_expired_date
        if self.org_main_cert_no:
            if hasattr(self.org_main_cert_no, 'to_alipay_dict'):
                params['org_main_cert_no'] = self.org_main_cert_no.to_alipay_dict()
            else:
                params['org_main_cert_no'] = self.org_main_cert_no
        if self.org_main_cert_picture:
            if hasattr(self.org_main_cert_picture, 'to_alipay_dict'):
                params['org_main_cert_picture'] = self.org_main_cert_picture.to_alipay_dict()
            else:
                params['org_main_cert_picture'] = self.org_main_cert_picture
        if self.org_name:
            if hasattr(self.org_name, 'to_alipay_dict'):
                params['org_name'] = self.org_name.to_alipay_dict()
            else:
                params['org_name'] = self.org_name
        if self.org_province:
            if hasattr(self.org_province, 'to_alipay_dict'):
                params['org_province'] = self.org_province.to_alipay_dict()
            else:
                params['org_province'] = self.org_province
        if self.org_type:
            if hasattr(self.org_type, 'to_alipay_dict'):
                params['org_type'] = self.org_type.to_alipay_dict()
            else:
                params['org_type'] = self.org_type
        if self.register_capital:
            if hasattr(self.register_capital, 'to_alipay_dict'):
                params['register_capital'] = self.register_capital.to_alipay_dict()
            else:
                params['register_capital'] = self.register_capital
        if self.remit_check:
            if hasattr(self.remit_check, 'to_alipay_dict'):
                params['remit_check'] = self.remit_check.to_alipay_dict()
            else:
                params['remit_check'] = self.remit_check
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCertifyInfoApplyModel()
        if 'agent_auth_letter_picture' in d:
            o.agent_auth_letter_picture = d['agent_auth_letter_picture']
        if 'agent_cert_card_assist_picture' in d:
            o.agent_cert_card_assist_picture = d['agent_cert_card_assist_picture']
        if 'agent_cert_card_info_picture' in d:
            o.agent_cert_card_info_picture = d['agent_cert_card_info_picture']
        if 'agent_cert_expired_date' in d:
            o.agent_cert_expired_date = d['agent_cert_expired_date']
        if 'agent_cert_no' in d:
            o.agent_cert_no = d['agent_cert_no']
        if 'agent_cert_type' in d:
            o.agent_cert_type = d['agent_cert_type']
        if 'agent_name' in d:
            o.agent_name = d['agent_name']
        if 'biz_from' in d:
            o.biz_from = d['biz_from']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'legal_cert_card_assist_picture' in d:
            o.legal_cert_card_assist_picture = d['legal_cert_card_assist_picture']
        if 'legal_cert_card_info_picture' in d:
            o.legal_cert_card_info_picture = d['legal_cert_card_info_picture']
        if 'legal_cert_expired_date' in d:
            o.legal_cert_expired_date = d['legal_cert_expired_date']
        if 'legal_cert_no' in d:
            o.legal_cert_no = d['legal_cert_no']
        if 'legal_cert_type' in d:
            o.legal_cert_type = d['legal_cert_type']
        if 'legal_name' in d:
            o.legal_name = d['legal_name']
        if 'org_address' in d:
            o.org_address = d['org_address']
        if 'org_business_scope' in d:
            o.org_business_scope = d['org_business_scope']
        if 'org_city' in d:
            o.org_city = d['org_city']
        if 'org_country' in d:
            o.org_country = d['org_country']
        if 'org_main_cert_expired_date' in d:
            o.org_main_cert_expired_date = d['org_main_cert_expired_date']
        if 'org_main_cert_no' in d:
            o.org_main_cert_no = d['org_main_cert_no']
        if 'org_main_cert_picture' in d:
            o.org_main_cert_picture = d['org_main_cert_picture']
        if 'org_name' in d:
            o.org_name = d['org_name']
        if 'org_province' in d:
            o.org_province = d['org_province']
        if 'org_type' in d:
            o.org_type = d['org_type']
        if 'register_capital' in d:
            o.register_capital = d['register_capital']
        if 'remit_check' in d:
            o.remit_check = d['remit_check']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayDataIotdataAnomalydetectionBaiVerifyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDataIotdataAnomalydetectionBaiVerifyResponse, self).__init__()
        self._event_detail = None
        self._event_type = None

    @property
    def event_detail(self):
        return self._event_detail

    @event_detail.setter
    def event_detail(self, value):
        self._event_detail = value
    @property
    def event_type(self):
        return self._event_type

    @event_type.setter
    def event_type(self, value):
        self._event_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayDataIotdataAnomalydetectionBaiVerifyResponse, self).parse_response_content(response_content)
        if 'event_detail' in response:
            self.event_detail = response['event_detail']
        if 'event_type' in response:
            self.event_type = response['event_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class UpgradeInfo(object):

    def __init__(self):
        self._upgrade_after = None
        self._upgrade_before = None
        self._upgrade_force = None
        self._upgrade_target = None

    @property
    def upgrade_after(self):
        return self._upgrade_after

    @upgrade_after.setter
    def upgrade_after(self, value):
        self._upgrade_after = value
    @property
    def upgrade_before(self):
        return self._upgrade_before

    @upgrade_before.setter
    def upgrade_before(self, value):
        self._upgrade_before = value
    @property
    def upgrade_force(self):
        return self._upgrade_force

    @upgrade_force.setter
    def upgrade_force(self, value):
        self._upgrade_force = value
    @property
    def upgrade_target(self):
        return self._upgrade_target

    @upgrade_target.setter
    def upgrade_target(self, value):
        self._upgrade_target = value


    def to_alipay_dict(self):
        params = dict()
        if self.upgrade_after:
            if hasattr(self.upgrade_after, 'to_alipay_dict'):
                params['upgrade_after'] = self.upgrade_after.to_alipay_dict()
            else:
                params['upgrade_after'] = self.upgrade_after
        if self.upgrade_before:
            if hasattr(self.upgrade_before, 'to_alipay_dict'):
                params['upgrade_before'] = self.upgrade_before.to_alipay_dict()
            else:
                params['upgrade_before'] = self.upgrade_before
        if self.upgrade_force:
            if hasattr(self.upgrade_force, 'to_alipay_dict'):
                params['upgrade_force'] = self.upgrade_force.to_alipay_dict()
            else:
                params['upgrade_force'] = self.upgrade_force
        if self.upgrade_target:
            if hasattr(self.upgrade_target, 'to_alipay_dict'):
                params['upgrade_target'] = self.upgrade_target.to_alipay_dict()
            else:
                params['upgrade_target'] = self.upgrade_target
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = UpgradeInfo()
        if 'upgrade_after' in d:
            o.upgrade_after = d['upgrade_after']
        if 'upgrade_before' in d:
            o.upgrade_before = d['upgrade_before']
        if 'upgrade_force' in d:
            o.upgrade_force = d['upgrade_force']
        if 'upgrade_target' in d:
            o.upgrade_target = d['upgrade_target']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ApplyCodeRequest import ApplyCodeRequest


class AntMerchantExpandScodeApplyModel(object):

    def __init__(self):
        self._apply_code_request = None

    @property
    def apply_code_request(self):
        return self._apply_code_request

    @apply_code_request.setter
    def apply_code_request(self, value):
        if isinstance(value, list):
            self._apply_code_request = list()
            for i in value:
                if isinstance(i, ApplyCodeRequest):
                    self._apply_code_request.append(i)
                else:
                    self._apply_code_request.append(ApplyCodeRequest.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.apply_code_request:
            if isinstance(self.apply_code_request, list):
                for i in range(0, len(self.apply_code_request)):
                    element = self.apply_code_request[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_code_request[i] = element.to_alipay_dict()
            if hasattr(self.apply_code_request, 'to_alipay_dict'):
                params['apply_code_request'] = self.apply_code_request.to_alipay_dict()
            else:
                params['apply_code_request'] = self.apply_code_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandScodeApplyModel()
        if 'apply_code_request' in d:
            o.apply_code_request = d['apply_code_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CodeResult import CodeResult


class ApplyCodeResult(object):

    def __init__(self):
        self._biz_id = None
        self._code_result = None
        self._error_code = None
        self._error_message = None
        self._success = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def code_result(self):
        return self._code_result

    @code_result.setter
    def code_result(self, value):
        if isinstance(value, CodeResult):
            self._code_result = value
        else:
            self._code_result = CodeResult.from_alipay_dict(value)
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.code_result:
            if hasattr(self.code_result, 'to_alipay_dict'):
                params['code_result'] = self.code_result.to_alipay_dict()
            else:
                params['code_result'] = self.code_result
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_message:
            if hasattr(self.error_message, 'to_alipay_dict'):
                params['error_message'] = self.error_message.to_alipay_dict()
            else:
                params['error_message'] = self.error_message
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApplyCodeResult()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'code_result' in d:
            o.code_result = d['code_result']
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_message' in d:
            o.error_message = d['error_message']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InvoiceResponsePageDTO import InvoiceResponsePageDTO


class AlipayBossFncGfsettleprodInvoiceBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossFncGfsettleprodInvoiceBatchqueryResponse, self).__init__()
        self._result_set = None

    @property
    def result_set(self):
        return self._result_set

    @result_set.setter
    def result_set(self, value):
        if isinstance(value, InvoiceResponsePageDTO):
            self._result_set = value
        else:
            self._result_set = InvoiceResponsePageDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayBossFncGfsettleprodInvoiceBatchqueryResponse, self).parse_response_content(response_content)
        if 'result_set' in response:
            self.result_set = response['result_set']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MCardDetail(object):

    def __init__(self):
        self._available_amount = None
        self._name = None
        self._pay_amount = None

    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_amount:
            if hasattr(self.available_amount, 'to_alipay_dict'):
                params['available_amount'] = self.available_amount.to_alipay_dict()
            else:
                params['available_amount'] = self.available_amount
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MCardDetail()
        if 'available_amount' in d:
            o.available_amount = d['available_amount']
        if 'name' in d:
            o.name = d['name']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppServiceListQueryModel(object):

    def __init__(self):
        self._category_id = None
        self._page_num = None
        self._page_size = None
        self._service_name = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def service_name(self):
        return self._service_name

    @service_name.setter
    def service_name(self, value):
        self._service_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.service_name:
            if hasattr(self.service_name, 'to_alipay_dict'):
                params['service_name'] = self.service_name.to_alipay_dict()
            else:
                params['service_name'] = self.service_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppServiceListQueryModel()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'service_name' in d:
            o.service_name = d['service_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MyObjectDdd(object):

    def __init__(self):
        self._item = None
        self._param = None

    @property
    def item(self):
        return self._item

    @item.setter
    def item(self, value):
        self._item = value
    @property
    def param(self):
        return self._param

    @param.setter
    def param(self, value):
        self._param = value


    def to_alipay_dict(self):
        params = dict()
        if self.item:
            if hasattr(self.item, 'to_alipay_dict'):
                params['item'] = self.item.to_alipay_dict()
            else:
                params['item'] = self.item
        if self.param:
            if hasattr(self.param, 'to_alipay_dict'):
                params['param'] = self.param.to_alipay_dict()
            else:
                params['param'] = self.param
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MyObjectDdd()
        if 'item' in d:
            o.item = d['item']
        if 'param' in d:
            o.param = d['param']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PortfolioOperatorInfo import PortfolioOperatorInfo
from alipay.aop.api.domain.PortfolioShop import PortfolioShop


class KoubeiServindustryPortfolioDataModifyModel(object):

    def __init__(self):
        self._cover_media_id = None
        self._cover_media_type = None
        self._portfolio_id = None
        self._portfolio_operator_info = None
        self._portfolio_shops = None
        self._title = None

    @property
    def cover_media_id(self):
        return self._cover_media_id

    @cover_media_id.setter
    def cover_media_id(self, value):
        self._cover_media_id = value
    @property
    def cover_media_type(self):
        return self._cover_media_type

    @cover_media_type.setter
    def cover_media_type(self, value):
        self._cover_media_type = value
    @property
    def portfolio_id(self):
        return self._portfolio_id

    @portfolio_id.setter
    def portfolio_id(self, value):
        self._portfolio_id = value
    @property
    def portfolio_operator_info(self):
        return self._portfolio_operator_info

    @portfolio_operator_info.setter
    def portfolio_operator_info(self, value):
        if isinstance(value, PortfolioOperatorInfo):
            self._portfolio_operator_info = value
        else:
            self._portfolio_operator_info = PortfolioOperatorInfo.from_alipay_dict(value)
    @property
    def portfolio_shops(self):
        return self._portfolio_shops

    @portfolio_shops.setter
    def portfolio_shops(self, value):
        if isinstance(value, list):
            self._portfolio_shops = list()
            for i in value:
                if isinstance(i, PortfolioShop):
                    self._portfolio_shops.append(i)
                else:
                    self._portfolio_shops.append(PortfolioShop.from_alipay_dict(i))
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.cover_media_id:
            if hasattr(self.cover_media_id, 'to_alipay_dict'):
                params['cover_media_id'] = self.cover_media_id.to_alipay_dict()
            else:
                params['cover_media_id'] = self.cover_media_id
        if self.cover_media_type:
            if hasattr(self.cover_media_type, 'to_alipay_dict'):
                params['cover_media_type'] = self.cover_media_type.to_alipay_dict()
            else:
                params['cover_media_type'] = self.cover_media_type
        if self.portfolio_id:
            if hasattr(self.portfolio_id, 'to_alipay_dict'):
                params['portfolio_id'] = self.portfolio_id.to_alipay_dict()
            else:
                params['portfolio_id'] = self.portfolio_id
        if self.portfolio_operator_info:
            if hasattr(self.portfolio_operator_info, 'to_alipay_dict'):
                params['portfolio_operator_info'] = self.portfolio_operator_info.to_alipay_dict()
            else:
                params['portfolio_operator_info'] = self.portfolio_operator_info
        if self.portfolio_shops:
            if isinstance(self.portfolio_shops, list):
                for i in range(0, len(self.portfolio_shops)):
                    element = self.portfolio_shops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.portfolio_shops[i] = element.to_alipay_dict()
            if hasattr(self.portfolio_shops, 'to_alipay_dict'):
                params['portfolio_shops'] = self.portfolio_shops.to_alipay_dict()
            else:
                params['portfolio_shops'] = self.portfolio_shops
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiServindustryPortfolioDataModifyModel()
        if 'cover_media_id' in d:
            o.cover_media_id = d['cover_media_id']
        if 'cover_media_type' in d:
            o.cover_media_type = d['cover_media_type']
        if 'portfolio_id' in d:
            o.portfolio_id = d['portfolio_id']
        if 'portfolio_operator_info' in d:
            o.portfolio_operator_info = d['portfolio_operator_info']
        if 'portfolio_shops' in d:
            o.portfolio_shops = d['portfolio_shops']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserPeerpayprodAgreementSignModel(object):

    def __init__(self):
        self._alipay_related_uid = None
        self._alipay_user_id = None
        self._quota = None
        self._relation_name = None
        self._request_from = None

    @property
    def alipay_related_uid(self):
        return self._alipay_related_uid

    @alipay_related_uid.setter
    def alipay_related_uid(self, value):
        self._alipay_related_uid = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def quota(self):
        return self._quota

    @quota.setter
    def quota(self, value):
        self._quota = value
    @property
    def relation_name(self):
        return self._relation_name

    @relation_name.setter
    def relation_name(self, value):
        self._relation_name = value
    @property
    def request_from(self):
        return self._request_from

    @request_from.setter
    def request_from(self, value):
        self._request_from = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_related_uid:
            if hasattr(self.alipay_related_uid, 'to_alipay_dict'):
                params['alipay_related_uid'] = self.alipay_related_uid.to_alipay_dict()
            else:
                params['alipay_related_uid'] = self.alipay_related_uid
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.quota:
            if hasattr(self.quota, 'to_alipay_dict'):
                params['quota'] = self.quota.to_alipay_dict()
            else:
                params['quota'] = self.quota
        if self.relation_name:
            if hasattr(self.relation_name, 'to_alipay_dict'):
                params['relation_name'] = self.relation_name.to_alipay_dict()
            else:
                params['relation_name'] = self.relation_name
        if self.request_from:
            if hasattr(self.request_from, 'to_alipay_dict'):
                params['request_from'] = self.request_from.to_alipay_dict()
            else:
                params['request_from'] = self.request_from
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserPeerpayprodAgreementSignModel()
        if 'alipay_related_uid' in d:
            o.alipay_related_uid = d['alipay_related_uid']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'quota' in d:
            o.quota = d['quota']
        if 'relation_name' in d:
            o.relation_name = d['relation_name']
        if 'request_from' in d:
            o.request_from = d['request_from']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class StepcounterDataInfo(object):

    def __init__(self):
        self._count = None
        self._count_date = None
        self._time_zone = None

    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def count_date(self):
        return self._count_date

    @count_date.setter
    def count_date(self, value):
        self._count_date = value
    @property
    def time_zone(self):
        return self._time_zone

    @time_zone.setter
    def time_zone(self, value):
        self._time_zone = value


    def to_alipay_dict(self):
        params = dict()
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.count_date:
            if hasattr(self.count_date, 'to_alipay_dict'):
                params['count_date'] = self.count_date.to_alipay_dict()
            else:
                params['count_date'] = self.count_date
        if self.time_zone:
            if hasattr(self.time_zone, 'to_alipay_dict'):
                params['time_zone'] = self.time_zone.to_alipay_dict()
            else:
                params['time_zone'] = self.time_zone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = StepcounterDataInfo()
        if 'count' in d:
            o.count = d['count']
        if 'count_date' in d:
            o.count_date = d['count_date']
        if 'time_zone' in d:
            o.time_zone = d['time_zone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserApplepayProvisioningbundleEffectModel(object):

    def __init__(self):
        self._event_type = None
        self._provisioning_bundle_identifier = None
        self._reference_identifier = None

    @property
    def event_type(self):
        return self._event_type

    @event_type.setter
    def event_type(self, value):
        self._event_type = value
    @property
    def provisioning_bundle_identifier(self):
        return self._provisioning_bundle_identifier

    @provisioning_bundle_identifier.setter
    def provisioning_bundle_identifier(self, value):
        self._provisioning_bundle_identifier = value
    @property
    def reference_identifier(self):
        return self._reference_identifier

    @reference_identifier.setter
    def reference_identifier(self, value):
        self._reference_identifier = value


    def to_alipay_dict(self):
        params = dict()
        if self.event_type:
            if hasattr(self.event_type, 'to_alipay_dict'):
                params['event_type'] = self.event_type.to_alipay_dict()
            else:
                params['event_type'] = self.event_type
        if self.provisioning_bundle_identifier:
            if hasattr(self.provisioning_bundle_identifier, 'to_alipay_dict'):
                params['provisioning_bundle_identifier'] = self.provisioning_bundle_identifier.to_alipay_dict()
            else:
                params['provisioning_bundle_identifier'] = self.provisioning_bundle_identifier
        if self.reference_identifier:
            if hasattr(self.reference_identifier, 'to_alipay_dict'):
                params['reference_identifier'] = self.reference_identifier.to_alipay_dict()
            else:
                params['reference_identifier'] = self.reference_identifier
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserApplepayProvisioningbundleEffectModel()
        if 'event_type' in d:
            o.event_type = d['event_type']
        if 'provisioning_bundle_identifier' in d:
            o.provisioning_bundle_identifier = d['provisioning_bundle_identifier']
        if 'reference_identifier' in d:
            o.reference_identifier = d['reference_identifier']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BizOrderQueryResponse import BizOrderQueryResponse


class AlipayOfflineMarketApplyorderBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOfflineMarketApplyorderBatchqueryResponse, self).__init__()
        self._biz_order_infos = None
        self._current_page_no = None
        self._page_size = None
        self._total_items = None
        self._total_page_no = None

    @property
    def biz_order_infos(self):
        return self._biz_order_infos

    @biz_order_infos.setter
    def biz_order_infos(self, value):
        if isinstance(value, list):
            self._biz_order_infos = list()
            for i in value:
                if isinstance(i, BizOrderQueryResponse):
                    self._biz_order_infos.append(i)
                else:
                    self._biz_order_infos.append(BizOrderQueryResponse.from_alipay_dict(i))
    @property
    def current_page_no(self):
        return self._current_page_no

    @current_page_no.setter
    def current_page_no(self, value):
        self._current_page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_items(self):
        return self._total_items

    @total_items.setter
    def total_items(self, value):
        self._total_items = value
    @property
    def total_page_no(self):
        return self._total_page_no

    @total_page_no.setter
    def total_page_no(self, value):
        self._total_page_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayOfflineMarketApplyorderBatchqueryResponse, self).parse_response_content(response_content)
        if 'biz_order_infos' in response:
            self.biz_order_infos = response['biz_order_infos']
        if 'current_page_no' in response:
            self.current_page_no = response['current_page_no']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_items' in response:
            self.total_items = response['total_items']
        if 'total_page_no' in response:
            self.total_page_no = response['total_page_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandIndirectOnlineCreateResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandIndirectOnlineCreateResponse, self).__init__()
        self._sub_merchant_id = None

    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandIndirectOnlineCreateResponse, self).parse_response_content(response_content)
        if 'sub_merchant_id' in response:
            self.sub_merchant_id = response['sub_merchant_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TemplateStyleDTO(object):

    def __init__(self):
        self._background_color = None

    @property
    def background_color(self):
        return self._background_color

    @background_color.setter
    def background_color(self, value):
        self._background_color = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_color:
            if hasattr(self.background_color, 'to_alipay_dict'):
                params['background_color'] = self.background_color.to_alipay_dict()
            else:
                params['background_color'] = self.background_color
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateStyleDTO()
        if 'background_color' in d:
            o.background_color = d['background_color']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFincoreFunddsAccountWitnessCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFincoreFunddsAccountWitnessCreateResponse, self).__init__()
        self._account_no = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayFincoreFunddsAccountWitnessCreateResponse, self).parse_response_content(response_content)
        if 'account_no' in response:
            self.account_no = response['account_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DiscountInfoData(object):

    def __init__(self):
        self._discount_amount = None
        self._discount_name = None
        self._discount_page_link = None
        self._discount_quantity = None
        self._external_discount_id = None

    @property
    def discount_amount(self):
        return self._discount_amount

    @discount_amount.setter
    def discount_amount(self, value):
        self._discount_amount = value
    @property
    def discount_name(self):
        return self._discount_name

    @discount_name.setter
    def discount_name(self, value):
        self._discount_name = value
    @property
    def discount_page_link(self):
        return self._discount_page_link

    @discount_page_link.setter
    def discount_page_link(self, value):
        self._discount_page_link = value
    @property
    def discount_quantity(self):
        return self._discount_quantity

    @discount_quantity.setter
    def discount_quantity(self, value):
        self._discount_quantity = value
    @property
    def external_discount_id(self):
        return self._external_discount_id

    @external_discount_id.setter
    def external_discount_id(self, value):
        self._external_discount_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.discount_amount:
            if hasattr(self.discount_amount, 'to_alipay_dict'):
                params['discount_amount'] = self.discount_amount.to_alipay_dict()
            else:
                params['discount_amount'] = self.discount_amount
        if self.discount_name:
            if hasattr(self.discount_name, 'to_alipay_dict'):
                params['discount_name'] = self.discount_name.to_alipay_dict()
            else:
                params['discount_name'] = self.discount_name
        if self.discount_page_link:
            if hasattr(self.discount_page_link, 'to_alipay_dict'):
                params['discount_page_link'] = self.discount_page_link.to_alipay_dict()
            else:
                params['discount_page_link'] = self.discount_page_link
        if self.discount_quantity:
            if hasattr(self.discount_quantity, 'to_alipay_dict'):
                params['discount_quantity'] = self.discount_quantity.to_alipay_dict()
            else:
                params['discount_quantity'] = self.discount_quantity
        if self.external_discount_id:
            if hasattr(self.external_discount_id, 'to_alipay_dict'):
                params['external_discount_id'] = self.external_discount_id.to_alipay_dict()
            else:
                params['external_discount_id'] = self.external_discount_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DiscountInfoData()
        if 'discount_amount' in d:
            o.discount_amount = d['discount_amount']
        if 'discount_name' in d:
            o.discount_name = d['discount_name']
        if 'discount_page_link' in d:
            o.discount_page_link = d['discount_page_link']
        if 'discount_quantity' in d:
            o.discount_quantity = d['discount_quantity']
        if 'external_discount_id' in d:
            o.external_discount_id = d['external_discount_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiMerchantBillQueryModel(object):

    def __init__(self):
        self._aggr_id = None
        self._end_time = None
        self._start_time = None

    @property
    def aggr_id(self):
        return self._aggr_id

    @aggr_id.setter
    def aggr_id(self, value):
        self._aggr_id = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.aggr_id:
            if hasattr(self.aggr_id, 'to_alipay_dict'):
                params['aggr_id'] = self.aggr_id.to_alipay_dict()
            else:
                params['aggr_id'] = self.aggr_id
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiMerchantBillQueryModel()
        if 'aggr_id' in d:
            o.aggr_id = d['aggr_id']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CPCommServices(object):

    def __init__(self):
        self._account = None
        self._account_type = None
        self._audit_desc = None
        self._audit_status = None
        self._category_name = None
        self._external_address_scan_result = None
        self._external_invoke_address = None
        self._gmt_created = None
        self._gmt_modified = None
        self._next_action = None
        self._qr_code_expires = None
        self._qr_code_image = None
        self._qr_code_type = None
        self._service_expires = None
        self._service_type = None
        self._status = None

    @property
    def account(self):
        return self._account

    @account.setter
    def account(self, value):
        self._account = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def audit_desc(self):
        return self._audit_desc

    @audit_desc.setter
    def audit_desc(self, value):
        self._audit_desc = value
    @property
    def audit_status(self):
        return self._audit_status

    @audit_status.setter
    def audit_status(self, value):
        self._audit_status = value
    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def external_address_scan_result(self):
        return self._external_address_scan_result

    @external_address_scan_result.setter
    def external_address_scan_result(self, value):
        self._external_address_scan_result = value
    @property
    def external_invoke_address(self):
        return self._external_invoke_address

    @external_invoke_address.setter
    def external_invoke_address(self, value):
        self._external_invoke_address = value
    @property
    def gmt_created(self):
        return self._gmt_created

    @gmt_created.setter
    def gmt_created(self, value):
        self._gmt_created = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def next_action(self):
        return self._next_action

    @next_action.setter
    def next_action(self, value):
        self._next_action = value
    @property
    def qr_code_expires(self):
        return self._qr_code_expires

    @qr_code_expires.setter
    def qr_code_expires(self, value):
        self._qr_code_expires = value
    @property
    def qr_code_image(self):
        return self._qr_code_image

    @qr_code_image.setter
    def qr_code_image(self, value):
        self._qr_code_image = value
    @property
    def qr_code_type(self):
        return self._qr_code_type

    @qr_code_type.setter
    def qr_code_type(self, value):
        self._qr_code_type = value
    @property
    def service_expires(self):
        return self._service_expires

    @service_expires.setter
    def service_expires(self, value):
        self._service_expires = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.account:
            if hasattr(self.account, 'to_alipay_dict'):
                params['account'] = self.account.to_alipay_dict()
            else:
                params['account'] = self.account
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.audit_desc:
            if hasattr(self.audit_desc, 'to_alipay_dict'):
                params['audit_desc'] = self.audit_desc.to_alipay_dict()
            else:
                params['audit_desc'] = self.audit_desc
        if self.audit_status:
            if hasattr(self.audit_status, 'to_alipay_dict'):
                params['audit_status'] = self.audit_status.to_alipay_dict()
            else:
                params['audit_status'] = self.audit_status
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.external_address_scan_result:
            if hasattr(self.external_address_scan_result, 'to_alipay_dict'):
                params['external_address_scan_result'] = self.external_address_scan_result.to_alipay_dict()
            else:
                params['external_address_scan_result'] = self.external_address_scan_result
        if self.external_invoke_address:
            if hasattr(self.external_invoke_address, 'to_alipay_dict'):
                params['external_invoke_address'] = self.external_invoke_address.to_alipay_dict()
            else:
                params['external_invoke_address'] = self.external_invoke_address
        if self.gmt_created:
            if hasattr(self.gmt_created, 'to_alipay_dict'):
                params['gmt_created'] = self.gmt_created.to_alipay_dict()
            else:
                params['gmt_created'] = self.gmt_created
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.next_action:
            if hasattr(self.next_action, 'to_alipay_dict'):
                params['next_action'] = self.next_action.to_alipay_dict()
            else:
                params['next_action'] = self.next_action
        if self.qr_code_expires:
            if hasattr(self.qr_code_expires, 'to_alipay_dict'):
                params['qr_code_expires'] = self.qr_code_expires.to_alipay_dict()
            else:
                params['qr_code_expires'] = self.qr_code_expires
        if self.qr_code_image:
            if hasattr(self.qr_code_image, 'to_alipay_dict'):
                params['qr_code_image'] = self.qr_code_image.to_alipay_dict()
            else:
                params['qr_code_image'] = self.qr_code_image
        if self.qr_code_type:
            if hasattr(self.qr_code_type, 'to_alipay_dict'):
                params['qr_code_type'] = self.qr_code_type.to_alipay_dict()
            else:
                params['qr_code_type'] = self.qr_code_type
        if self.service_expires:
            if hasattr(self.service_expires, 'to_alipay_dict'):
                params['service_expires'] = self.service_expires.to_alipay_dict()
            else:
                params['service_expires'] = self.service_expires
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CPCommServices()
        if 'account' in d:
            o.account = d['account']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'audit_desc' in d:
            o.audit_desc = d['audit_desc']
        if 'audit_status' in d:
            o.audit_status = d['audit_status']
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'external_address_scan_result' in d:
            o.external_address_scan_result = d['external_address_scan_result']
        if 'external_invoke_address' in d:
            o.external_invoke_address = d['external_invoke_address']
        if 'gmt_created' in d:
            o.gmt_created = d['gmt_created']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'next_action' in d:
            o.next_action = d['next_action']
        if 'qr_code_expires' in d:
            o.qr_code_expires = d['qr_code_expires']
        if 'qr_code_image' in d:
            o.qr_code_image = d['qr_code_image']
        if 'qr_code_type' in d:
            o.qr_code_type = d['qr_code_type']
        if 'service_expires' in d:
            o.service_expires = d['service_expires']
        if 'service_type' in d:
            o.service_type = d['service_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReportBasicInfo import ReportBasicInfo


class AnttechBlockchainDefinInsuranceReportCreateModel(object):

    def __init__(self):
        self._business_code = None
        self._parm = None
        self._platform_access_type = None
        self._platform_code = None
        self._product_code = None
        self._report_basic_info = None
        self._report_subject_information = None
        self._trade_no = None

    @property
    def business_code(self):
        return self._business_code

    @business_code.setter
    def business_code(self, value):
        self._business_code = value
    @property
    def parm(self):
        return self._parm

    @parm.setter
    def parm(self, value):
        self._parm = value
    @property
    def platform_access_type(self):
        return self._platform_access_type

    @platform_access_type.setter
    def platform_access_type(self, value):
        self._platform_access_type = value
    @property
    def platform_code(self):
        return self._platform_code

    @platform_code.setter
    def platform_code(self, value):
        self._platform_code = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def report_basic_info(self):
        return self._report_basic_info

    @report_basic_info.setter
    def report_basic_info(self, value):
        if isinstance(value, ReportBasicInfo):
            self._report_basic_info = value
        else:
            self._report_basic_info = ReportBasicInfo.from_alipay_dict(value)
    @property
    def report_subject_information(self):
        return self._report_subject_information

    @report_subject_information.setter
    def report_subject_information(self, value):
        self._report_subject_information = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_code:
            if hasattr(self.business_code, 'to_alipay_dict'):
                params['business_code'] = self.business_code.to_alipay_dict()
            else:
                params['business_code'] = self.business_code
        if self.parm:
            if hasattr(self.parm, 'to_alipay_dict'):
                params['parm'] = self.parm.to_alipay_dict()
            else:
                params['parm'] = self.parm
        if self.platform_access_type:
            if hasattr(self.platform_access_type, 'to_alipay_dict'):
                params['platform_access_type'] = self.platform_access_type.to_alipay_dict()
            else:
                params['platform_access_type'] = self.platform_access_type
        if self.platform_code:
            if hasattr(self.platform_code, 'to_alipay_dict'):
                params['platform_code'] = self.platform_code.to_alipay_dict()
            else:
                params['platform_code'] = self.platform_code
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.report_basic_info:
            if hasattr(self.report_basic_info, 'to_alipay_dict'):
                params['report_basic_info'] = self.report_basic_info.to_alipay_dict()
            else:
                params['report_basic_info'] = self.report_basic_info
        if self.report_subject_information:
            if hasattr(self.report_subject_information, 'to_alipay_dict'):
                params['report_subject_information'] = self.report_subject_information.to_alipay_dict()
            else:
                params['report_subject_information'] = self.report_subject_information
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinInsuranceReportCreateModel()
        if 'business_code' in d:
            o.business_code = d['business_code']
        if 'parm' in d:
            o.parm = d['parm']
        if 'platform_access_type' in d:
            o.platform_access_type = d['platform_access_type']
        if 'platform_code' in d:
            o.platform_code = d['platform_code']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'report_basic_info' in d:
            o.report_basic_info = d['report_basic_info']
        if 'report_subject_information' in d:
            o.report_subject_information = d['report_subject_information']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





# -*- coding: utf-8 -*-
'''
Created on 2017-12-20

@author: liuqun
'''


def add_start_end(key, startMarker, endMarker):
    if key.find(startMarker) < 0:
        key = startMarker + key
    if key.find(endMarker) < 0:
        key = key + endMarker
    return key



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OwnedSystemPrivacyField import OwnedSystemPrivacyField


class AlipayOpenMiniPrivacySystemfieldQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniPrivacySystemfieldQueryResponse, self).__init__()
        self._system_privacy_fields = None

    @property
    def system_privacy_fields(self):
        return self._system_privacy_fields

    @system_privacy_fields.setter
    def system_privacy_fields(self, value):
        if isinstance(value, list):
            self._system_privacy_fields = list()
            for i in value:
                if isinstance(i, OwnedSystemPrivacyField):
                    self._system_privacy_fields.append(i)
                else:
                    self._system_privacy_fields.append(OwnedSystemPrivacyField.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniPrivacySystemfieldQueryResponse, self).parse_response_content(response_content)
        if 'system_privacy_fields' in response:
            self.system_privacy_fields = response['system_privacy_fields']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MiniPackageInfo(object):

    def __init__(self):
        self._doc_url = None
        self._package_desc = None
        self._package_name = None
        self._package_open_type = None
        self._status = None

    @property
    def doc_url(self):
        return self._doc_url

    @doc_url.setter
    def doc_url(self, value):
        self._doc_url = value
    @property
    def package_desc(self):
        return self._package_desc

    @package_desc.setter
    def package_desc(self, value):
        self._package_desc = value
    @property
    def package_name(self):
        return self._package_name

    @package_name.setter
    def package_name(self, value):
        self._package_name = value
    @property
    def package_open_type(self):
        return self._package_open_type

    @package_open_type.setter
    def package_open_type(self, value):
        self._package_open_type = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.doc_url:
            if hasattr(self.doc_url, 'to_alipay_dict'):
                params['doc_url'] = self.doc_url.to_alipay_dict()
            else:
                params['doc_url'] = self.doc_url
        if self.package_desc:
            if hasattr(self.package_desc, 'to_alipay_dict'):
                params['package_desc'] = self.package_desc.to_alipay_dict()
            else:
                params['package_desc'] = self.package_desc
        if self.package_name:
            if hasattr(self.package_name, 'to_alipay_dict'):
                params['package_name'] = self.package_name.to_alipay_dict()
            else:
                params['package_name'] = self.package_name
        if self.package_open_type:
            if hasattr(self.package_open_type, 'to_alipay_dict'):
                params['package_open_type'] = self.package_open_type.to_alipay_dict()
            else:
                params['package_open_type'] = self.package_open_type
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MiniPackageInfo()
        if 'doc_url' in d:
            o.doc_url = d['doc_url']
        if 'package_desc' in d:
            o.package_desc = d['package_desc']
        if 'package_name' in d:
            o.package_name = d['package_name']
        if 'package_open_type' in d:
            o.package_open_type = d['package_open_type']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccountFreeze(object):

    def __init__(self):
        self._freeze_amount = None
        self._freeze_name = None
        self._freeze_type = None

    @property
    def freeze_amount(self):
        return self._freeze_amount

    @freeze_amount.setter
    def freeze_amount(self, value):
        self._freeze_amount = value
    @property
    def freeze_name(self):
        return self._freeze_name

    @freeze_name.setter
    def freeze_name(self, value):
        self._freeze_name = value
    @property
    def freeze_type(self):
        return self._freeze_type

    @freeze_type.setter
    def freeze_type(self, value):
        self._freeze_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.freeze_amount:
            if hasattr(self.freeze_amount, 'to_alipay_dict'):
                params['freeze_amount'] = self.freeze_amount.to_alipay_dict()
            else:
                params['freeze_amount'] = self.freeze_amount
        if self.freeze_name:
            if hasattr(self.freeze_name, 'to_alipay_dict'):
                params['freeze_name'] = self.freeze_name.to_alipay_dict()
            else:
                params['freeze_name'] = self.freeze_name
        if self.freeze_type:
            if hasattr(self.freeze_type, 'to_alipay_dict'):
                params['freeze_type'] = self.freeze_type.to_alipay_dict()
            else:
                params['freeze_type'] = self.freeze_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccountFreeze()
        if 'freeze_amount' in d:
            o.freeze_amount = d['freeze_amount']
        if 'freeze_name' in d:
            o.freeze_name = d['freeze_name']
        if 'freeze_type' in d:
            o.freeze_type = d['freeze_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LinkMallCallBackInfo import LinkMallCallBackInfo


class AntfortuneYebEntityequityVerifyModel(object):

    def __init__(self):
        self._appid = None
        self._info = None
        self._signature = None

    @property
    def appid(self):
        return self._appid

    @appid.setter
    def appid(self, value):
        self._appid = value
    @property
    def info(self):
        return self._info

    @info.setter
    def info(self, value):
        if isinstance(value, LinkMallCallBackInfo):
            self._info = value
        else:
            self._info = LinkMallCallBackInfo.from_alipay_dict(value)
    @property
    def signature(self):
        return self._signature

    @signature.setter
    def signature(self, value):
        self._signature = value


    def to_alipay_dict(self):
        params = dict()
        if self.appid:
            if hasattr(self.appid, 'to_alipay_dict'):
                params['appid'] = self.appid.to_alipay_dict()
            else:
                params['appid'] = self.appid
        if self.info:
            if hasattr(self.info, 'to_alipay_dict'):
                params['info'] = self.info.to_alipay_dict()
            else:
                params['info'] = self.info
        if self.signature:
            if hasattr(self.signature, 'to_alipay_dict'):
                params['signature'] = self.signature.to_alipay_dict()
            else:
                params['signature'] = self.signature
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntfortuneYebEntityequityVerifyModel()
        if 'appid' in d:
            o.appid = d['appid']
        if 'info' in d:
            o.info = d['info']
        if 'signature' in d:
            o.signature = d['signature']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SceneDataQueryParam(object):

    def __init__(self):
        self._app_seqno = None
        self._ip_id = None
        self._ip_role_id = None
        self._site = None
        self._site_user_id = None

    @property
    def app_seqno(self):
        return self._app_seqno

    @app_seqno.setter
    def app_seqno(self, value):
        self._app_seqno = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_seqno:
            if hasattr(self.app_seqno, 'to_alipay_dict'):
                params['app_seqno'] = self.app_seqno.to_alipay_dict()
            else:
                params['app_seqno'] = self.app_seqno
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_user_id:
            if hasattr(self.site_user_id, 'to_alipay_dict'):
                params['site_user_id'] = self.site_user_id.to_alipay_dict()
            else:
                params['site_user_id'] = self.site_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SceneDataQueryParam()
        if 'app_seqno' in d:
            o.app_seqno = d['app_seqno']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'site' in d:
            o.site = d['site']
        if 'site_user_id' in d:
            o.site_user_id = d['site_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceCityfacilitatorVoucherBatchqueryModel(object):

    def __init__(self):
        self._city_code = None
        self._trade_nos = None

    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def trade_nos(self):
        return self._trade_nos

    @trade_nos.setter
    def trade_nos(self, value):
        if isinstance(value, list):
            self._trade_nos = list()
            for i in value:
                self._trade_nos.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.trade_nos:
            if isinstance(self.trade_nos, list):
                for i in range(0, len(self.trade_nos)):
                    element = self.trade_nos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.trade_nos[i] = element.to_alipay_dict()
            if hasattr(self.trade_nos, 'to_alipay_dict'):
                params['trade_nos'] = self.trade_nos.to_alipay_dict()
            else:
                params['trade_nos'] = self.trade_nos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceCityfacilitatorVoucherBatchqueryModel()
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'trade_nos' in d:
            o.trade_nos = d['trade_nos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsObject(object):

    def __init__(self):
        self._insured_object_id = None
        self._insured_object_info = None
        self._type = None

    @property
    def insured_object_id(self):
        return self._insured_object_id

    @insured_object_id.setter
    def insured_object_id(self, value):
        self._insured_object_id = value
    @property
    def insured_object_info(self):
        return self._insured_object_info

    @insured_object_info.setter
    def insured_object_info(self, value):
        self._insured_object_info = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.insured_object_id:
            if hasattr(self.insured_object_id, 'to_alipay_dict'):
                params['insured_object_id'] = self.insured_object_id.to_alipay_dict()
            else:
                params['insured_object_id'] = self.insured_object_id
        if self.insured_object_info:
            if hasattr(self.insured_object_info, 'to_alipay_dict'):
                params['insured_object_info'] = self.insured_object_info.to_alipay_dict()
            else:
                params['insured_object_info'] = self.insured_object_info
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsObject()
        if 'insured_object_id' in d:
            o.insured_object_id = d['insured_object_id']
        if 'insured_object_info' in d:
            o.insured_object_info = d['insured_object_info']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ServiceSubTaskQueryOpenapiResult import ServiceSubTaskQueryOpenapiResult


class AlipayCommerceTransportIntelligentizeServicetaskQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportIntelligentizeServicetaskQueryResponse, self).__init__()
        self._end_time = None
        self._ext_info = None
        self._result_code = None
        self._result_msg = None
        self._service_task_id = None
        self._service_task_result = None
        self._service_task_status = None
        self._service_task_type = None
        self._start_time = None
        self._sub_task_list = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_msg(self):
        return self._result_msg

    @result_msg.setter
    def result_msg(self, value):
        self._result_msg = value
    @property
    def service_task_id(self):
        return self._service_task_id

    @service_task_id.setter
    def service_task_id(self, value):
        self._service_task_id = value
    @property
    def service_task_result(self):
        return self._service_task_result

    @service_task_result.setter
    def service_task_result(self, value):
        self._service_task_result = value
    @property
    def service_task_status(self):
        return self._service_task_status

    @service_task_status.setter
    def service_task_status(self, value):
        self._service_task_status = value
    @property
    def service_task_type(self):
        return self._service_task_type

    @service_task_type.setter
    def service_task_type(self, value):
        self._service_task_type = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def sub_task_list(self):
        return self._sub_task_list

    @sub_task_list.setter
    def sub_task_list(self, value):
        if isinstance(value, list):
            self._sub_task_list = list()
            for i in value:
                if isinstance(i, ServiceSubTaskQueryOpenapiResult):
                    self._sub_task_list.append(i)
                else:
                    self._sub_task_list.append(ServiceSubTaskQueryOpenapiResult.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportIntelligentizeServicetaskQueryResponse, self).parse_response_content(response_content)
        if 'end_time' in response:
            self.end_time = response['end_time']
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_msg' in response:
            self.result_msg = response['result_msg']
        if 'service_task_id' in response:
            self.service_task_id = response['service_task_id']
        if 'service_task_result' in response:
            self.service_task_result = response['service_task_result']
        if 'service_task_status' in response:
            self.service_task_status = response['service_task_status']
        if 'service_task_type' in response:
            self.service_task_type = response['service_task_type']
        if 'start_time' in response:
            self.start_time = response['start_time']
        if 'sub_task_list' in response:
            self.sub_task_list = response['sub_task_list']
